# `relationalai.std.strings`

The `relationalai.std.strings` namespace contains functions for working with strings.

- [`strings.concat()`](./concat.md)
- [`strings.contains()`](./contains.md)
- [`strings.ends_with()`](./ends_with.md)
- [`strings.join()`](./join.md)
- [`strings.length()`](./length.md)
- [`strings.like()`](./like.md)
- [`strings.lowercase()`](./lowercase.md)
- [`strings.regex_compile()`](./regex_compile.md)
- [`strings.regex_match()`](./regex_match.md)
- [`strings.replace()`](./replace.md)
- [`strings.split()`](./split.md)
- [`strings.split_part()`](./split_part.md)
- [`strings.uppercase()`](./uppercase.md)
